@@ -1,6 +1,6 @@
 /*
  * Caudium - An extensible World Wide Web server
- * Copyright  2000-2002 The Caudium Group
+ * Copyright  2000-2004 The Caudium Group
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,9 +18,9 @@
  *
  */
 
-/* $Id: ultraparse.c,v 1.6.2.3 2002/01/02 00:55:52 kiwi Exp $ */
+/* $Id: ultraparse.c,v 1.10.2.2 2004/01/15 01:58:18 grendel Exp $ */
 #include "global.h"
-RCSID("$Id: ultraparse.c,v 1.6.2.3 2002/01/02 00:55:52 kiwi Exp $");
+RCSID("$Id: ultraparse.c,v 1.10.2.2 2004/01/15 01:58:18 grendel Exp $");
 #include "caudium_util.h"
 
 #include <stdio.h>
@@ -310,13 +310,13 @@ static void f_ultraparse( INT32 args )
   struct mapping *tmpdest = NULL;
   /*  struct mapping *hits30x     = allocate_mapping(2);*/
   
-  if(args>6 && sp[-1].type == T_INT) {
-    offs0 = sp[-1].u.integer;
+  if(args>6 && Pike_sp[-1].type == T_INT) {
+    offs0 = Pike_sp[-1].u.integer;
     pop_n_elems(1);
     --args;
   }
-  if(args>5 && sp[-1].type == T_STRING) {
-    notref = sp[-1].u.string->str;
+  if(args>5 && Pike_sp[-1].type == T_STRING) {
+    notref = Pike_sp[-1].u.string->str;
     pop_n_elems(1);
     --args;
   }
